@@ -7,7 +7,7 @@ use Types::Standard qw/Maybe/;
 use Types::Path::Tiny qw/Path/;
 use String::ShellQuote;
 
-our $VERSION = "0.05";
+our $VERSION = "0.06";
 
 =head1 NAME
 
@@ -56,6 +56,18 @@ has ssh_options => (is => 'lazy', default => sub { [] });
 has logfile     => (is => 'rw', isa => Maybe[Path], coerce => Path->coercion, clearer => 1);
 has noop        => (is => 'rw', default => sub { 0 });
 
+before logfile => sub {
+    my ($self, $logfile) = @_;
+    
+    return unless $logfile;
+
+    die "Logfile is not writeable: $logfile\n"
+        unless -w $logfile;
+
+    die "Logfile is not a file: $logfile\n"
+        unless -f $logfile;
+};
+
 sub remote {
     my ($self, $user, $host, @cmd) = @_;
 
